@@ -9,7 +9,7 @@ my @variables = qw(
    custom_lib_path use_plucene indexing_directory enable_page_deletion
    admin_pass stylesheet_url site_name navbar_on_home_page home_name
    site_desc default_city default_country contact_email default_language
-   formatting_rules_node backlinks_in_title template_path custom_template_path
+   formatting_rules_node formatting_rules_link backlinks_in_title template_path custom_template_path
    geo_handler ellipsoid
 );
 my @questions = map { $_ . "__qu" } @variables;
@@ -56,6 +56,7 @@ sub _init {
     my ($self, %args) = @_;
 
     # Here are the defaults for the variable values.
+    # Don't forget to add to INSTALL when changing these.
     my %defaults = (
                      dbtype => "postgres",
                      script_name => "wiki.cgi",
@@ -68,10 +69,11 @@ sub _init {
                      navbar_on_home_page => 1,
                      home_name => "Home",
                      site_desc => "A default configuration of OpenGuides",
-                     default_city => "London",
-                     default_country => "United Kingdom",
+                     default_city => "",
+                     default_country => "",
                      default_language => "en",
                      formatting_rules_node => "Text Formatting Examples",
+                     formatting_rules_link => "http://openguides.org/page/text_formatting",
                      backlinks_in_title => 0,
                      geo_handler => 1,
                      ellipsoid => "International"
@@ -101,6 +103,7 @@ sub _init {
     }
 
     # And the questions.
+    # Don't forget to add to INSTALL when changing these.
     my %questions = (
         dbtype => "What type of database do you want the site to run on?  postgres/mysql/sqlite",
         dbname => "What's the name of the database that this site runs on?",
@@ -126,7 +129,8 @@ sub _init {
         default_country => "What country is the site based in?",
         contact_email => "Contact email address for the site administrator?",
         default_language => "What language will the site be in? (Please give an ISO language code.)",
-        formatting_rules_node => "What's the name of the node to use for the text formatting rules link?",
+        formatting_rules_node => "What's the name of the node or page to use for the text formatting rules link (this is by default an external document, but if you make formatting_rules_link empty, it will be a wiki node instead",
+	formatting_rules_link => "What URL do you want to use for the text formatting rules (leave blank to use a wiki node instead)?",
         backlinks_in_title => "Make node titles link to node backlinks (C2 style)?",
         ellipsoid => "Which ellipsoid do you want to use? (eg 'Airy', 'WGS-84')",
     );
@@ -209,6 +213,8 @@ sub script_url {
 
 =item * formatting_rules_node (default: C<Text Formatting Examples>)
 
+=item * formatting_rules_link (default: C<http://openguides.org/page/text_formatting>
+
 =item * backlinks_in_title (default: false)
 
 =item * geo_handler (default: C<1>)
